@@ -23,22 +23,33 @@ import _ast
 
 try:
     import pep8
-    HAS_PEP8 = True
-    PEP8_VERSION = tuple([int(x) for x in pep8.__version__.split('.')])
 except ImportError:
     HAS_PEP8 = False
+else:
+    HAS_PEP8 = True
+    PEP8_VERSION = tuple([int(x) for x in pep8.__version__.split('.')])
 
 try:
     import pyflakes.checker
-    HAS_PYFLAKES = True
 except ImportError:
     HAS_PYFLAKES = False
+else:
+    HAS_PYFLAKES = True
 
 try:
     import pyjslint
-    HAS_JSLINT = True
 except ImportError:
     HAS_JSLINT = False
+else:
+    HAS_JSLINT = True
+
+try:
+    import pep257
+except ImportError:
+    HAS_PEP257 = False
+else:
+    HAS_PEP257 = True
+
 
 from hghooks import CheckerManager, re_options
 
@@ -188,7 +199,7 @@ def pyflakeshook(ui, repo, hooktype, node, pending, **kwargs):
 
 def jslint_check(data, filename):
     output = pyjslint.check_JSLint(data)
-    if len(output) > 0:
+    if output:
         print >> sys.stderr, "%s: problem decoding source" % (filename, )
         print >> sys.stderr, '\n'.join(output)
         return 1
@@ -208,3 +219,26 @@ def jslinthook(ui, repo, hooktype, node, pending, **kwargs):
     checker_manager = CheckerManager(ui, repo, node, 'no-jslint',
                                      extension='.js')
     return checker_manager.check(jslint_checker)
+
+
+def pep257_check(data, filename):
+    output = pep257.check_source(data, filename)
+    if output:
+        print >> sys.stderr, '\n'.join([str(out) for out in output])
+        return 1
+    return 0
+
+
+def pep257_checker(files_to_check, msg):
+    return sum([pep257_check(data, filename)
+                for filename, data in files_to_check.items()])
+
+
+def pep257hook(ui, repo, hooktype, node, pending, **kwargs):
+    if not HAS_PEP257:
+        ui.warn('You need the pep257 python module to use the pep257hook')
+        return True  # Failure
+
+    checker_manager = CheckerManager(ui, repo, node, 'no-pep257',
+                                     extension='.py')
+    return checker_manager.check(pep257_checker)
